==> react-bootstrap-0.2.0.tgz: package/es/components/Card/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Button from '../Button';
import Icon from '../Icon';

import Container from './Container';
import Header from './Header';
import Body from './Body';
import Footer from './Footer';

import colors from '../../utils/colors';

import './index.css';

var Card = (_temp2 = _class = function (_Component) {
  _inherits(Card, _Component);

  function Card() {
    var _temp, _this, _ret;

    _classCallCheck(this, Card);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showBodyAndFooter: true
    }, _this.toggleBodyAndFooter = function () {
      return _this.setState({
        showBodyAndFooter: !_this.state.showBodyAndFooter
      }, _this.props.onToggle);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Card.prototype.render = function render() {
    var _cn;

    var _props = this.props,
        color = _props.color,
        title = _props.title,
        controls = _props.controls,
        collapsible = _props.collapsible,
        closed = _props.closed,
        customBody = _props.customBody,
        footer = _props.footer,
        fullHeight = _props.fullHeight,
        className = _props.className,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['color', 'title', 'controls', 'collapsible', 'closed', 'customBody', 'footer', 'fullHeight', 'className', 'children']);

    var showBodyAndFooter = closed === null ? this.state.showBodyAndFooter : !closed;

    return React.createElement(
      Container,
      _extends({}, props, {
        className: cn((_cn = {
          'card-on-full-height': fullHeight
        }, _cn['bg-' + color] = color, _cn['text-white'] = color && color !== 'light' && color !== 'warning', _cn), className)
      }),
      title || controls ? React.createElement(
        Header,
        null,
        React.createElement(
          'div',
          { className: 'card-header-inner' },
          typeof title === 'string' ? React.createElement(
            'div',
            { className: 'card-header-title' },
            title
          ) : title,
          typeof controls === 'string' ? React.createElement(
            'div',
            null,
            controls
          ) : controls,
          collapsible && !fullHeight ? React.createElement(
            Button,
            {
              color: color || 'light',
              className: 'card-toggle',
              onClick: this.toggleBodyAndFooter
            },
            React.createElement(Icon, { name: 'chevron-' + (showBodyAndFooter ? 'down' : 'up') })
          ) : null
        )
      ) : null,
      React.createElement(
        Body,
        {
          custom: customBody,
          className: cn({
            'd-none': !showBodyAndFooter,
            'card-body-on-full-height': fullHeight,
            'rounded-top': fullHeight && !(title || controls),
            'rounded-bottom': fullHeight && !footer
          })
        },
        children
      ),
      footer ? React.createElement(
        Footer,
        { className: cn({ 'd-none': !showBodyAndFooter }) },
        footer
      ) : null
    );
  };

  return Card;
}(Component), _class.defaultProps = {
  color: '',
  title: null,
  controls: null,
  collapsible: true,
  closed: null,
  onToggle: function onToggle() {},
  customBody: false,
  footer: null,
  fullHeight: false,
  className: '',
  children: null
}, _class.Container = Container, _class.Header = Header, _class.Body = Body, _class.Footer = Footer, _temp2);
Card.propTypes = process.env.NODE_ENV !== "production" ? {
  color: PropTypes.oneOf([].concat(colors, [''])),
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  controls: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  collapsible: PropTypes.bool,
  closed: PropTypes.oneOf([true, false, null]),
  onToggle: PropTypes.func,
  customBody: PropTypes.bool,
  footer: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  fullHeight: PropTypes.bool,
  className: PropTypes.string,
  children: PropTypes.node
} : {};


export default Card;

==> react-bootstrap-0.2.2.tgz: package/es/components/Card/index.js <==
var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _class, _temp2;

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _possibleConstructorReturn(self, call) { if (!self) { throw new ReferenceError("this hasn't been initialised - super() hasn't been called"); } return call && (typeof call === "object" || typeof call === "function") ? call : self; }

function _inherits(subClass, superClass) { if (typeof superClass !== "function" && superClass !== null) { throw new TypeError("Super expression must either be null or a function, not " + typeof superClass); } subClass.prototype = Object.create(superClass && superClass.prototype, { constructor: { value: subClass, enumerable: false, writable: true, configurable: true } }); if (superClass) Object.setPrototypeOf ? Object.setPrototypeOf(subClass, superClass) : subClass.__proto__ = superClass; }

import React, { Component } from 'react';
import PropTypes from 'prop-types';
import cn from 'classnames';

import Button from '../Button';
import Icon from '../Icon';

import Container from './Container';
import Header from './Header';
import Body from './Body';
import Footer from './Footer';

import colors from '../../utils/colors';

import './index.css';

var Card = (_temp2 = _class = function (_Component) {
  _inherits(Card, _Component);

  function Card() {
    var _temp, _this, _ret;

    _classCallCheck(this, Card);

    for (var _len = arguments.length, args = Array(_len), _key = 0; _key < _len; _key++) {
      args[_key] = arguments[_key];
    }

    return _ret = (_temp = (_this = _possibleConstructorReturn(this, _Component.call.apply(_Component, [this].concat(args))), _this), _this.state = {
      showBodyAndFooter: true
    }, _this.toggleBodyAndFooter = function () {
      return _this.setState(function (state) {
        return {
          showBodyAndFooter: !state.showBodyAndFooter
        };
      }, _this.props.onToggle);
    }, _temp), _possibleConstructorReturn(_this, _ret);
  }

  Card.prototype.render = function render() {
    var _cn;

    var _props = this.props,
        color = _props.color,
        title = _props.title,
        controls = _props.controls,
        collapsible = _props.collapsible,
        closed = _props.closed,
        customBody = _props.customBody,
        footer = _props.footer,
        fullHeight = _props.fullHeight,
        className = _props.className,
        children = _props.children,
        props = _objectWithoutProperties(_props, ['color', 'title', 'controls', 'collapsible', 'closed', 'customBody', 'footer', 'fullHeight', 'className', 'children']);

    var showBodyAndFooter = closed === null ? this.state.showBodyAndFooter : !closed;

    return React.createElement(
      Container,
      _extends({}, props, {
        className: cn((_cn = {
          'card-on-full-height': fullHeight
        }, _cn['bg-' + color] = color, _cn['text-white'] = color && color !== 'light' && color !== 'warning', _cn), className)
      }),
      title || controls ? React.createElement(
        Header,
        null,
        React.createElement(
          'div',
          { className: 'card-header-inner' },
          typeof title === 'string' ? React.createElement(
            'div',
            { className: 'card-header-title' },
            title
          ) : title,
          typeof controls === 'string' ? React.createElement(
            'div',
            null,
            controls
          ) : controls,
          collapsible && !fullHeight ? React.createElement(
            Button,
            {
              color: color || 'light',
              className: 'card-toggle',
              onClick: this.toggleBodyAndFooter
            },
            React.createElement(Icon, { name: 'chevron-' + (showBodyAndFooter ? 'down' : 'up') })
          ) : null
        )
      ) : null,
      React.createElement(
        Body,
        {
          custom: customBody,
          className: cn({
            'd-none': !showBodyAndFooter,
            'card-body-on-full-height': fullHeight,
            'rounded-top': fullHeight && !(title || controls),
            'rounded-bottom': fullHeight && !footer
          })
        },
        children
      ),
      footer ? React.createElement(
        Footer,
        { className: cn({ 'd-none': !showBodyAndFooter }) },
        footer
      ) : null
    );
  };

  return Card;
}(Component), _class.defaultProps = {
  color: '',
  title: null,
  controls: null,
  collapsible: true,
  closed: null,
  onToggle: function onToggle() {},
  customBody: false,
  footer: null,
  fullHeight: false,
  className: '',
  children: null
}, _class.Container = Container, _class.Header = Header, _class.Body = Body, _class.Footer = Footer, _temp2);
Card.propTypes = process.env.NODE_ENV !== "production" ? {
  color: PropTypes.oneOf([].concat(colors, [''])),
  title: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  controls: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  collapsible: PropTypes.bool,
  closed: PropTypes.oneOf([true, false, null]),
  onToggle: PropTypes.func,
  customBody: PropTypes.bool,
  footer: PropTypes.oneOfType([PropTypes.string, PropTypes.node]),
  fullHeight: PropTypes.bool,
  className: PropTypes.string,
  children: PropTypes.node
} : {};


export default Card;
